fermi surface 2d plotting Options — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# fermi surface 2d plotting Options

## add_axes_labels

description:

  Boolean to add axes labels

value:

  True

## add_legend

description:

  Boolean to add legend

value:

  False

## plot_color_bar

description:

  Boolean to plot the color bar

value:

  False

## cmap

description:

  The colormap used for the plot.

value:

  jet

## clim

description:

  The color scale for the color bar

value:

  [None, None]

## color

description:

  The colors for the spin plot lines.

value:

  [‘blue’, ‘red’]

## linestyle

description:

  The linestyles for the spin plot lines.

value:

  [‘solid’, ‘dashed’]

## linewidth

description:

  The linewidth of the fermi surface

value:

  0.2

## no_arrow

description:

  Boolean to use no arrows to represent the spin texture

value:

  False

## arrow_color

description:

  The linestyles for the spin plot lines.

value:

  None

## arrow_density

description:

  The arrow density for the spin texture

value:

  10

## arrow_size

description:

  The arrow size for the spin texture

value:

  3

## spin_projection

description:

  The projection for the color scale for spin texture

value:

  z^2

## marker

description:

  Controls the marker used for the spin plot

value:

  .

## dpi

description:

  The dpi value to save the image as

value:

  figure

## x_label

description:

  The x label of the plot

value:

  $k_{x}$ ($AA^{-1}$)

## y_label

description:

  The x label of the plot

value:

  $k_{y}$ ($AA^{-1}$)